# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CheckEmailBlacklistResults(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'domain': 'str',
        'requested_ip_address': 'str',
        'requested_mx_host': 'str',
        'status': 'str',
        'listed': 'bool',
        'checked_ip_addresses': 'list[EmailBlacklistIpResult]',
        'checked_zone_count': 'int',
        'total_listings': 'int',
        'warnings': 'list[str]',
        'errors': 'list[str]'
    }

    attribute_map = {
        'domain': 'domain',
        'requested_ip_address': 'requestedIpAddress',
        'requested_mx_host': 'requestedMxHost',
        'status': 'status',
        'listed': 'listed',
        'checked_ip_addresses': 'checkedIpAddresses',
        'checked_zone_count': 'checkedZoneCount',
        'total_listings': 'totalListings',
        'warnings': 'warnings',
        'errors': 'errors'
    }

    def __init__(self, domain=None, requested_ip_address=None, requested_mx_host=None, status=None, listed=None, checked_ip_addresses=None, checked_zone_count=None, total_listings=None, warnings=None, errors=None, local_vars_configuration=None):  # noqa: E501
        """CheckEmailBlacklistResults - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._domain = None
        self._requested_ip_address = None
        self._requested_mx_host = None
        self._status = None
        self._listed = None
        self._checked_ip_addresses = None
        self._checked_zone_count = None
        self._total_listings = None
        self._warnings = None
        self._errors = None
        self.discriminator = None

        self.domain = domain
        self.requested_ip_address = requested_ip_address
        self.requested_mx_host = requested_mx_host
        self.status = status
        self.listed = listed
        self.checked_ip_addresses = checked_ip_addresses
        self.checked_zone_count = checked_zone_count
        self.total_listings = total_listings
        self.warnings = warnings
        self.errors = errors

    @property
    def domain(self):
        """Gets the domain of this CheckEmailBlacklistResults.  # noqa: E501


        :return: The domain of this CheckEmailBlacklistResults.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this CheckEmailBlacklistResults.


        :param domain: The domain of this CheckEmailBlacklistResults.  # noqa: E501
        :type: str
        """

        self._domain = domain

    @property
    def requested_ip_address(self):
        """Gets the requested_ip_address of this CheckEmailBlacklistResults.  # noqa: E501


        :return: The requested_ip_address of this CheckEmailBlacklistResults.  # noqa: E501
        :rtype: str
        """
        return self._requested_ip_address

    @requested_ip_address.setter
    def requested_ip_address(self, requested_ip_address):
        """Sets the requested_ip_address of this CheckEmailBlacklistResults.


        :param requested_ip_address: The requested_ip_address of this CheckEmailBlacklistResults.  # noqa: E501
        :type: str
        """

        self._requested_ip_address = requested_ip_address

    @property
    def requested_mx_host(self):
        """Gets the requested_mx_host of this CheckEmailBlacklistResults.  # noqa: E501


        :return: The requested_mx_host of this CheckEmailBlacklistResults.  # noqa: E501
        :rtype: str
        """
        return self._requested_mx_host

    @requested_mx_host.setter
    def requested_mx_host(self, requested_mx_host):
        """Sets the requested_mx_host of this CheckEmailBlacklistResults.


        :param requested_mx_host: The requested_mx_host of this CheckEmailBlacklistResults.  # noqa: E501
        :type: str
        """

        self._requested_mx_host = requested_mx_host

    @property
    def status(self):
        """Gets the status of this CheckEmailBlacklistResults.  # noqa: E501


        :return: The status of this CheckEmailBlacklistResults.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this CheckEmailBlacklistResults.


        :param status: The status of this CheckEmailBlacklistResults.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["HEALTHY", "DEGRADED", "CRITICAL", "FAILED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def listed(self):
        """Gets the listed of this CheckEmailBlacklistResults.  # noqa: E501


        :return: The listed of this CheckEmailBlacklistResults.  # noqa: E501
        :rtype: bool
        """
        return self._listed

    @listed.setter
    def listed(self, listed):
        """Sets the listed of this CheckEmailBlacklistResults.


        :param listed: The listed of this CheckEmailBlacklistResults.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and listed is None:  # noqa: E501
            raise ValueError("Invalid value for `listed`, must not be `None`")  # noqa: E501

        self._listed = listed

    @property
    def checked_ip_addresses(self):
        """Gets the checked_ip_addresses of this CheckEmailBlacklistResults.  # noqa: E501


        :return: The checked_ip_addresses of this CheckEmailBlacklistResults.  # noqa: E501
        :rtype: list[EmailBlacklistIpResult]
        """
        return self._checked_ip_addresses

    @checked_ip_addresses.setter
    def checked_ip_addresses(self, checked_ip_addresses):
        """Sets the checked_ip_addresses of this CheckEmailBlacklistResults.


        :param checked_ip_addresses: The checked_ip_addresses of this CheckEmailBlacklistResults.  # noqa: E501
        :type: list[EmailBlacklistIpResult]
        """
        if self.local_vars_configuration.client_side_validation and checked_ip_addresses is None:  # noqa: E501
            raise ValueError("Invalid value for `checked_ip_addresses`, must not be `None`")  # noqa: E501

        self._checked_ip_addresses = checked_ip_addresses

    @property
    def checked_zone_count(self):
        """Gets the checked_zone_count of this CheckEmailBlacklistResults.  # noqa: E501


        :return: The checked_zone_count of this CheckEmailBlacklistResults.  # noqa: E501
        :rtype: int
        """
        return self._checked_zone_count

    @checked_zone_count.setter
    def checked_zone_count(self, checked_zone_count):
        """Sets the checked_zone_count of this CheckEmailBlacklistResults.


        :param checked_zone_count: The checked_zone_count of this CheckEmailBlacklistResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and checked_zone_count is None:  # noqa: E501
            raise ValueError("Invalid value for `checked_zone_count`, must not be `None`")  # noqa: E501

        self._checked_zone_count = checked_zone_count

    @property
    def total_listings(self):
        """Gets the total_listings of this CheckEmailBlacklistResults.  # noqa: E501


        :return: The total_listings of this CheckEmailBlacklistResults.  # noqa: E501
        :rtype: int
        """
        return self._total_listings

    @total_listings.setter
    def total_listings(self, total_listings):
        """Sets the total_listings of this CheckEmailBlacklistResults.


        :param total_listings: The total_listings of this CheckEmailBlacklistResults.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_listings is None:  # noqa: E501
            raise ValueError("Invalid value for `total_listings`, must not be `None`")  # noqa: E501

        self._total_listings = total_listings

    @property
    def warnings(self):
        """Gets the warnings of this CheckEmailBlacklistResults.  # noqa: E501


        :return: The warnings of this CheckEmailBlacklistResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this CheckEmailBlacklistResults.


        :param warnings: The warnings of this CheckEmailBlacklistResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and warnings is None:  # noqa: E501
            raise ValueError("Invalid value for `warnings`, must not be `None`")  # noqa: E501

        self._warnings = warnings

    @property
    def errors(self):
        """Gets the errors of this CheckEmailBlacklistResults.  # noqa: E501


        :return: The errors of this CheckEmailBlacklistResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this CheckEmailBlacklistResults.


        :param errors: The errors of this CheckEmailBlacklistResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and errors is None:  # noqa: E501
            raise ValueError("Invalid value for `errors`, must not be `None`")  # noqa: E501

        self._errors = errors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CheckEmailBlacklistResults):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CheckEmailBlacklistResults):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.ai_controller_api import AIControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestAIControllerApi(unittest.TestCase):
    """AIControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.ai_controller_api.AIControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_transformer(self):
        """Test case for create_transformer

        Create a transformer for reuse in automations  # noqa: E501
        """
        pass

    def test_create_transformer_mappings(self):
        """Test case for create_transformer_mappings

        Create transformer mapping  # noqa: E501
        """
        pass

    def test_delete_all_transformer_mappings(self):
        """Test case for delete_all_transformer_mappings

        Delete all transformer mapping  # noqa: E501
        """
        pass

    def test_delete_transformer(self):
        """Test case for delete_transformer

        Delete a transformer  # noqa: E501
        """
        pass

    def test_delete_transformer_mapping(self):
        """Test case for delete_transformer_mapping

        Delete transformer mapping  # noqa: E501
        """
        pass

    def test_delete_transformers(self):
        """Test case for delete_transformers

        Delete all transformers  # noqa: E501
        """
        pass

    def test_export_transformer_results(self):
        """Test case for export_transformer_results

        Export transformer results  # noqa: E501
        """
        pass

    def test_generate_structured_content_from_attachment(self):
        """Test case for generate_structured_content_from_attachment

        Generate structured content for an attachment  # noqa: E501
        """
        pass

    def test_generate_structured_content_from_email(self):
        """Test case for generate_structured_content_from_email

        Generate structured content for an email  # noqa: E501
        """
        pass

    def test_generate_structured_content_from_sms(self):
        """Test case for generate_structured_content_from_sms

        Generate structured content for a TXT message  # noqa: E501
        """
        pass

    def test_get_export_transformer_results_job(self):
        """Test case for get_export_transformer_results_job

        Get export transformer results job  # noqa: E501
        """
        pass

    def test_get_transformer(self):
        """Test case for get_transformer

        Get a transformer  # noqa: E501
        """
        pass

    def test_get_transformer_mapping(self):
        """Test case for get_transformer_mapping

        Get transformer mapping  # noqa: E501
        """
        pass

    def test_get_transformer_mappings(self):
        """Test case for get_transformer_mappings

        Get transformer mappings  # noqa: E501
        """
        pass

    def test_get_transformer_result(self):
        """Test case for get_transformer_result

        Get transformer result  # noqa: E501
        """
        pass

    def test_get_transformer_results(self):
        """Test case for get_transformer_results

        Get transformer results  # noqa: E501
        """
        pass

    def test_get_transformer_results_table(self):
        """Test case for get_transformer_results_table

        Get transformer results table  # noqa: E501
        """
        pass

    def test_get_transformers(self):
        """Test case for get_transformers

        List transformers  # noqa: E501
        """
        pass

    def test_invoke_transformer(self):
        """Test case for invoke_transformer

        Invoke a transformer  # noqa: E501
        """
        pass

    def test_test_transformer_mapping_match(self):
        """Test case for test_transformer_mapping_match

        Test transformer mapping match result  # noqa: E501
        """
        pass

    def test_validate_structured_output_schema(self):
        """Test case for validate_structured_output_schema

        Validate structured content schema  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class InboxReplierDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'inbox_id': 'str',
        'name': 'str',
        'field': 'str',
        'match': 'str',
        'reply_to': 'str',
        'subject': 'str',
        '_from': 'str',
        'charset': 'str',
        'is_html': 'bool',
        'template_id': 'str',
        'template_variables': 'dict(str, object)',
        'ignore_reply_to': 'bool',
        'created_at': 'datetime',
        'should': 'str',
        'match_options': 'InboxAutomationMatchOptions'
    }

    attribute_map = {
        'id': 'id',
        'inbox_id': 'inboxId',
        'name': 'name',
        'field': 'field',
        'match': 'match',
        'reply_to': 'replyTo',
        'subject': 'subject',
        '_from': 'from',
        'charset': 'charset',
        'is_html': 'isHTML',
        'template_id': 'templateId',
        'template_variables': 'templateVariables',
        'ignore_reply_to': 'ignoreReplyTo',
        'created_at': 'createdAt',
        'should': 'should',
        'match_options': 'matchOptions'
    }

    def __init__(self, id=None, inbox_id=None, name=None, field=None, match=None, reply_to=None, subject=None, _from=None, charset=None, is_html=None, template_id=None, template_variables=None, ignore_reply_to=None, created_at=None, should=None, match_options=None, local_vars_configuration=None):  # noqa: E501
        """InboxReplierDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._inbox_id = None
        self._name = None
        self._field = None
        self._match = None
        self._reply_to = None
        self._subject = None
        self.__from = None
        self._charset = None
        self._is_html = None
        self._template_id = None
        self._template_variables = None
        self._ignore_reply_to = None
        self._created_at = None
        self._should = None
        self._match_options = None
        self.discriminator = None

        self.id = id
        self.inbox_id = inbox_id
        self.name = name
        self.field = field
        self.match = match
        self.reply_to = reply_to
        self.subject = subject
        self._from = _from
        self.charset = charset
        self.is_html = is_html
        self.template_id = template_id
        self.template_variables = template_variables
        self.ignore_reply_to = ignore_reply_to
        self.created_at = created_at
        self.should = should
        self.match_options = match_options

    @property
    def id(self):
        """Gets the id of this InboxReplierDto.  # noqa: E501


        :return: The id of this InboxReplierDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InboxReplierDto.


        :param id: The id of this InboxReplierDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def inbox_id(self):
        """Gets the inbox_id of this InboxReplierDto.  # noqa: E501


        :return: The inbox_id of this InboxReplierDto.  # noqa: E501
        :rtype: str
        """
        return self._inbox_id

    @inbox_id.setter
    def inbox_id(self, inbox_id):
        """Sets the inbox_id of this InboxReplierDto.


        :param inbox_id: The inbox_id of this InboxReplierDto.  # noqa: E501
        :type: str
        """

        self._inbox_id = inbox_id

    @property
    def name(self):
        """Gets the name of this InboxReplierDto.  # noqa: E501


        :return: The name of this InboxReplierDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InboxReplierDto.


        :param name: The name of this InboxReplierDto.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def field(self):
        """Gets the field of this InboxReplierDto.  # noqa: E501


        :return: The field of this InboxReplierDto.  # noqa: E501
        :rtype: str
        """
        return self._field

    @field.setter
    def field(self, field):
        """Sets the field of this InboxReplierDto.


        :param field: The field of this InboxReplierDto.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"RECIPIENTS", "SENDER", "SUBJECT", "ATTACHMENTS", "ATTACHMENT_FILENAME", "ATTACHMENT_TEXT"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and field not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `field` ({0}), must be one of {1}"  # noqa: E501
                .format(field, allowed_values)
            )

        self._field = field

    @property
    def match(self):
        """Gets the match of this InboxReplierDto.  # noqa: E501


        :return: The match of this InboxReplierDto.  # noqa: E501
        :rtype: str
        """
        return self._match

    @match.setter
    def match(self, match):
        """Sets the match of this InboxReplierDto.


        :param match: The match of this InboxReplierDto.  # noqa: E501
        :type: str
        """

        self._match = match

    @property
    def reply_to(self):
        """Gets the reply_to of this InboxReplierDto.  # noqa: E501


        :return: The reply_to of this InboxReplierDto.  # noqa: E501
        :rtype: str
        """
        return self._reply_to

    @reply_to.setter
    def reply_to(self, reply_to):
        """Sets the reply_to of this InboxReplierDto.


        :param reply_to: The reply_to of this InboxReplierDto.  # noqa: E501
        :type: str
        """

        self._reply_to = reply_to

    @property
    def subject(self):
        """Gets the subject of this InboxReplierDto.  # noqa: E501


        :return: The subject of this InboxReplierDto.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this InboxReplierDto.


        :param subject: The subject of this InboxReplierDto.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def _from(self):
        """Gets the _from of this InboxReplierDto.  # noqa: E501


        :return: The _from of this InboxReplierDto.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this InboxReplierDto.


        :param _from: The _from of this InboxReplierDto.  # noqa: E501
        :type: str
        """

        self.__from = _from

    @property
    def charset(self):
        """Gets the charset of this InboxReplierDto.  # noqa: E501


        :return: The charset of this InboxReplierDto.  # noqa: E501
        :rtype: str
        """
        return self._charset

    @charset.setter
    def charset(self, charset):
        """Sets the charset of this InboxReplierDto.


        :param charset: The charset of this InboxReplierDto.  # noqa: E501
        :type: str
        """

        self._charset = charset

    @property
    def is_html(self):
        """Gets the is_html of this InboxReplierDto.  # noqa: E501


        :return: The is_html of this InboxReplierDto.  # noqa: E501
        :rtype: bool
        """
        return self._is_html

    @is_html.setter
    def is_html(self, is_html):
        """Sets the is_html of this InboxReplierDto.


        :param is_html: The is_html of this InboxReplierDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and is_html is None:  # noqa: E501
            raise ValueError("Invalid value for `is_html`, must not be `None`")  # noqa: E501

        self._is_html = is_html

    @property
    def template_id(self):
        """Gets the template_id of this InboxReplierDto.  # noqa: E501


        :return: The template_id of this InboxReplierDto.  # noqa: E501
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this InboxReplierDto.


        :param template_id: The template_id of this InboxReplierDto.  # noqa: E501
        :type: str
        """

        self._template_id = template_id

    @property
    def template_variables(self):
        """Gets the template_variables of this InboxReplierDto.  # noqa: E501


        :return: The template_variables of this InboxReplierDto.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._template_variables

    @template_variables.setter
    def template_variables(self, template_variables):
        """Sets the template_variables of this InboxReplierDto.


        :param template_variables: The template_variables of this InboxReplierDto.  # noqa: E501
        :type: dict(str, object)
        """

        self._template_variables = template_variables

    @property
    def ignore_reply_to(self):
        """Gets the ignore_reply_to of this InboxReplierDto.  # noqa: E501


        :return: The ignore_reply_to of this InboxReplierDto.  # noqa: E501
        :rtype: bool
        """
        return self._ignore_reply_to

    @ignore_reply_to.setter
    def ignore_reply_to(self, ignore_reply_to):
        """Sets the ignore_reply_to of this InboxReplierDto.


        :param ignore_reply_to: The ignore_reply_to of this InboxReplierDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and ignore_reply_to is None:  # noqa: E501
            raise ValueError("Invalid value for `ignore_reply_to`, must not be `None`")  # noqa: E501

        self._ignore_reply_to = ignore_reply_to

    @property
    def created_at(self):
        """Gets the created_at of this InboxReplierDto.  # noqa: E501


        :return: The created_at of this InboxReplierDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this InboxReplierDto.


        :param created_at: The created_at of this InboxReplierDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def should(self):
        """Gets the should of this InboxReplierDto.  # noqa: E501

        Comparison mode for inbox automation matching.  # noqa: E501

        :return: The should of this InboxReplierDto.  # noqa: E501
        :rtype: str
        """
        return self._should

    @should.setter
    def should(self, should):
        """Sets the should of this InboxReplierDto.

        Comparison mode for inbox automation matching.  # noqa: E501

        :param should: The should of this InboxReplierDto.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"WILDCARD", "MATCH", "CONTAIN", "EQUAL"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and should not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `should` ({0}), must be one of {1}"  # noqa: E501
                .format(should, allowed_values)
            )

        self._should = should

    @property
    def match_options(self):
        """Gets the match_options of this InboxReplierDto.  # noqa: E501


        :return: The match_options of this InboxReplierDto.  # noqa: E501
        :rtype: InboxAutomationMatchOptions
        """
        return self._match_options

    @match_options.setter
    def match_options(self, match_options):
        """Sets the match_options of this InboxReplierDto.


        :param match_options: The match_options of this InboxReplierDto.  # noqa: E501
        :type: InboxAutomationMatchOptions
        """

        self._match_options = match_options

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InboxReplierDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InboxReplierDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.campaign_probe_controller_api import CampaignProbeControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestCampaignProbeControllerApi(unittest.TestCase):
    """CampaignProbeControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.campaign_probe_controller_api.CampaignProbeControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_compare_campaign_probe_runs(self):
        """Test case for compare_campaign_probe_runs

        Compare two campaign probe runs  # noqa: E501
        """
        pass

    def test_create_campaign_probe(self):
        """Test case for create_campaign_probe

        Create campaign probe  # noqa: E501
        """
        pass

    def test_delete_campaign_probe(self):
        """Test case for delete_campaign_probe

        Delete campaign probe  # noqa: E501
        """
        pass

    def test_get_campaign_probe(self):
        """Test case for get_campaign_probe

        Get campaign probe  # noqa: E501
        """
        pass

    def test_get_campaign_probe_insights(self):
        """Test case for get_campaign_probe_insights

        Get campaign probe insights  # noqa: E501
        """
        pass

    def test_get_campaign_probe_run(self):
        """Test case for get_campaign_probe_run

        Get campaign probe run  # noqa: E501
        """
        pass

    def test_get_campaign_probe_runs(self):
        """Test case for get_campaign_probe_runs

        List campaign probe runs  # noqa: E501
        """
        pass

    def test_get_campaign_probe_series(self):
        """Test case for get_campaign_probe_series

        Get campaign probe trend series  # noqa: E501
        """
        pass

    def test_get_campaign_probes(self):
        """Test case for get_campaign_probes

        List campaign probes  # noqa: E501
        """
        pass

    def test_run_campaign_probe_now(self):
        """Test case for run_campaign_probe_now

        Run campaign probe now  # noqa: E501
        """
        pass

    def test_run_due_campaign_probes(self):
        """Test case for run_due_campaign_probes

        Run due campaign probes for user  # noqa: E501
        """
        pass

    def test_update_campaign_probe(self):
        """Test case for update_campaign_probe

        Update campaign probe  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class ExportTransformerOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ai_transform_id': 'str',
        'ai_mapping_id': 'str',
        'flatten_arrays': 'bool',
        'since': 'datetime',
        'before': 'datetime',
        'format': 'str',
        'inbox_id': 'str',
        'phone_id': 'str',
        'email_id': 'str',
        'sms_id': 'str',
        'attachment_id': 'str',
        'include_meta_data': 'bool',
        'delimiter': 'str',
        'array_separator': 'str',
        'include_meta_data_columns': 'list[str]'
    }

    attribute_map = {
        'ai_transform_id': 'aiTransformId',
        'ai_mapping_id': 'aiMappingId',
        'flatten_arrays': 'flattenArrays',
        'since': 'since',
        'before': 'before',
        'format': 'format',
        'inbox_id': 'inboxId',
        'phone_id': 'phoneId',
        'email_id': 'emailId',
        'sms_id': 'smsId',
        'attachment_id': 'attachmentId',
        'include_meta_data': 'includeMetaData',
        'delimiter': 'delimiter',
        'array_separator': 'arraySeparator',
        'include_meta_data_columns': 'includeMetaDataColumns'
    }

    def __init__(self, ai_transform_id=None, ai_mapping_id=None, flatten_arrays=None, since=None, before=None, format=None, inbox_id=None, phone_id=None, email_id=None, sms_id=None, attachment_id=None, include_meta_data=None, delimiter=None, array_separator=None, include_meta_data_columns=None, local_vars_configuration=None):  # noqa: E501
        """ExportTransformerOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._ai_transform_id = None
        self._ai_mapping_id = None
        self._flatten_arrays = None
        self._since = None
        self._before = None
        self._format = None
        self._inbox_id = None
        self._phone_id = None
        self._email_id = None
        self._sms_id = None
        self._attachment_id = None
        self._include_meta_data = None
        self._delimiter = None
        self._array_separator = None
        self._include_meta_data_columns = None
        self.discriminator = None

        self.ai_transform_id = ai_transform_id
        self.ai_mapping_id = ai_mapping_id
        self.flatten_arrays = flatten_arrays
        self.since = since
        self.before = before
        self.format = format
        self.inbox_id = inbox_id
        self.phone_id = phone_id
        self.email_id = email_id
        self.sms_id = sms_id
        self.attachment_id = attachment_id
        self.include_meta_data = include_meta_data
        self.delimiter = delimiter
        self.array_separator = array_separator
        self.include_meta_data_columns = include_meta_data_columns

    @property
    def ai_transform_id(self):
        """Gets the ai_transform_id of this ExportTransformerOptions.  # noqa: E501


        :return: The ai_transform_id of this ExportTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._ai_transform_id

    @ai_transform_id.setter
    def ai_transform_id(self, ai_transform_id):
        """Sets the ai_transform_id of this ExportTransformerOptions.


        :param ai_transform_id: The ai_transform_id of this ExportTransformerOptions.  # noqa: E501
        :type: str
        """

        self._ai_transform_id = ai_transform_id

    @property
    def ai_mapping_id(self):
        """Gets the ai_mapping_id of this ExportTransformerOptions.  # noqa: E501


        :return: The ai_mapping_id of this ExportTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._ai_mapping_id

    @ai_mapping_id.setter
    def ai_mapping_id(self, ai_mapping_id):
        """Sets the ai_mapping_id of this ExportTransformerOptions.


        :param ai_mapping_id: The ai_mapping_id of this ExportTransformerOptions.  # noqa: E501
        :type: str
        """

        self._ai_mapping_id = ai_mapping_id

    @property
    def flatten_arrays(self):
        """Gets the flatten_arrays of this ExportTransformerOptions.  # noqa: E501


        :return: The flatten_arrays of this ExportTransformerOptions.  # noqa: E501
        :rtype: bool
        """
        return self._flatten_arrays

    @flatten_arrays.setter
    def flatten_arrays(self, flatten_arrays):
        """Sets the flatten_arrays of this ExportTransformerOptions.


        :param flatten_arrays: The flatten_arrays of this ExportTransformerOptions.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and flatten_arrays is None:  # noqa: E501
            raise ValueError("Invalid value for `flatten_arrays`, must not be `None`")  # noqa: E501

        self._flatten_arrays = flatten_arrays

    @property
    def since(self):
        """Gets the since of this ExportTransformerOptions.  # noqa: E501


        :return: The since of this ExportTransformerOptions.  # noqa: E501
        :rtype: datetime
        """
        return self._since

    @since.setter
    def since(self, since):
        """Sets the since of this ExportTransformerOptions.


        :param since: The since of this ExportTransformerOptions.  # noqa: E501
        :type: datetime
        """

        self._since = since

    @property
    def before(self):
        """Gets the before of this ExportTransformerOptions.  # noqa: E501


        :return: The before of this ExportTransformerOptions.  # noqa: E501
        :rtype: datetime
        """
        return self._before

    @before.setter
    def before(self, before):
        """Sets the before of this ExportTransformerOptions.


        :param before: The before of this ExportTransformerOptions.  # noqa: E501
        :type: datetime
        """

        self._before = before

    @property
    def format(self):
        """Gets the format of this ExportTransformerOptions.  # noqa: E501


        :return: The format of this ExportTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this ExportTransformerOptions.


        :param format: The format of this ExportTransformerOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and format is None:  # noqa: E501
            raise ValueError("Invalid value for `format`, must not be `None`")  # noqa: E501
        allowed_values = ["CSV", "EXCEL", "XML", "JSON"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and format not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `format` ({0}), must be one of {1}"  # noqa: E501
                .format(format, allowed_values)
            )

        self._format = format

    @property
    def inbox_id(self):
        """Gets the inbox_id of this ExportTransformerOptions.  # noqa: E501


        :return: The inbox_id of this ExportTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._inbox_id

    @inbox_id.setter
    def inbox_id(self, inbox_id):
        """Sets the inbox_id of this ExportTransformerOptions.


        :param inbox_id: The inbox_id of this ExportTransformerOptions.  # noqa: E501
        :type: str
        """

        self._inbox_id = inbox_id

    @property
    def phone_id(self):
        """Gets the phone_id of this ExportTransformerOptions.  # noqa: E501


        :return: The phone_id of this ExportTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._phone_id

    @phone_id.setter
    def phone_id(self, phone_id):
        """Sets the phone_id of this ExportTransformerOptions.


        :param phone_id: The phone_id of this ExportTransformerOptions.  # noqa: E501
        :type: str
        """

        self._phone_id = phone_id

    @property
    def email_id(self):
        """Gets the email_id of this ExportTransformerOptions.  # noqa: E501


        :return: The email_id of this ExportTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._email_id

    @email_id.setter
    def email_id(self, email_id):
        """Sets the email_id of this ExportTransformerOptions.


        :param email_id: The email_id of this ExportTransformerOptions.  # noqa: E501
        :type: str
        """

        self._email_id = email_id

    @property
    def sms_id(self):
        """Gets the sms_id of this ExportTransformerOptions.  # noqa: E501


        :return: The sms_id of this ExportTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._sms_id

    @sms_id.setter
    def sms_id(self, sms_id):
        """Sets the sms_id of this ExportTransformerOptions.


        :param sms_id: The sms_id of this ExportTransformerOptions.  # noqa: E501
        :type: str
        """

        self._sms_id = sms_id

    @property
    def attachment_id(self):
        """Gets the attachment_id of this ExportTransformerOptions.  # noqa: E501


        :return: The attachment_id of this ExportTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._attachment_id

    @attachment_id.setter
    def attachment_id(self, attachment_id):
        """Sets the attachment_id of this ExportTransformerOptions.


        :param attachment_id: The attachment_id of this ExportTransformerOptions.  # noqa: E501
        :type: str
        """

        self._attachment_id = attachment_id

    @property
    def include_meta_data(self):
        """Gets the include_meta_data of this ExportTransformerOptions.  # noqa: E501


        :return: The include_meta_data of this ExportTransformerOptions.  # noqa: E501
        :rtype: bool
        """
        return self._include_meta_data

    @include_meta_data.setter
    def include_meta_data(self, include_meta_data):
        """Sets the include_meta_data of this ExportTransformerOptions.


        :param include_meta_data: The include_meta_data of this ExportTransformerOptions.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and include_meta_data is None:  # noqa: E501
            raise ValueError("Invalid value for `include_meta_data`, must not be `None`")  # noqa: E501

        self._include_meta_data = include_meta_data

    @property
    def delimiter(self):
        """Gets the delimiter of this ExportTransformerOptions.  # noqa: E501


        :return: The delimiter of this ExportTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._delimiter

    @delimiter.setter
    def delimiter(self, delimiter):
        """Sets the delimiter of this ExportTransformerOptions.


        :param delimiter: The delimiter of this ExportTransformerOptions.  # noqa: E501
        :type: str
        """

        self._delimiter = delimiter

    @property
    def array_separator(self):
        """Gets the array_separator of this ExportTransformerOptions.  # noqa: E501


        :return: The array_separator of this ExportTransformerOptions.  # noqa: E501
        :rtype: str
        """
        return self._array_separator

    @array_separator.setter
    def array_separator(self, array_separator):
        """Sets the array_separator of this ExportTransformerOptions.


        :param array_separator: The array_separator of this ExportTransformerOptions.  # noqa: E501
        :type: str
        """

        self._array_separator = array_separator

    @property
    def include_meta_data_columns(self):
        """Gets the include_meta_data_columns of this ExportTransformerOptions.  # noqa: E501


        :return: The include_meta_data_columns of this ExportTransformerOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._include_meta_data_columns

    @include_meta_data_columns.setter
    def include_meta_data_columns(self, include_meta_data_columns):
        """Sets the include_meta_data_columns of this ExportTransformerOptions.


        :param include_meta_data_columns: The include_meta_data_columns of this ExportTransformerOptions.  # noqa: E501
        :type: list[str]
        """

        self._include_meta_data_columns = include_meta_data_columns

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExportTransformerOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ExportTransformerOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class EmailThreadProjection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        '_from': 'str',
        'subject': 'str',
        'sender': 'SenderProjection',
        'recipients': 'EmailRecipientsProjection',
        'user_id': 'str',
        'inbox_id': 'str',
        'updated_at': 'datetime',
        'created_at': 'datetime',
        'to': 'list[str]',
        'cc': 'list[str]',
        'bcc': 'list[str]',
        'has_attachments': 'bool',
        'unread': 'bool',
        'message_count': 'int',
        'last_body_excerpt': 'str',
        'last_text_excerpt': 'str',
        'last_created_at': 'datetime',
        'last_from': 'str',
        'last_sender': 'SenderProjection'
    }

    attribute_map = {
        'id': 'id',
        '_from': 'from',
        'subject': 'subject',
        'sender': 'sender',
        'recipients': 'recipients',
        'user_id': 'userId',
        'inbox_id': 'inboxId',
        'updated_at': 'updatedAt',
        'created_at': 'createdAt',
        'to': 'to',
        'cc': 'cc',
        'bcc': 'bcc',
        'has_attachments': 'hasAttachments',
        'unread': 'unread',
        'message_count': 'messageCount',
        'last_body_excerpt': 'lastBodyExcerpt',
        'last_text_excerpt': 'lastTextExcerpt',
        'last_created_at': 'lastCreatedAt',
        'last_from': 'lastFrom',
        'last_sender': 'lastSender'
    }

    def __init__(self, id=None, _from=None, subject=None, sender=None, recipients=None, user_id=None, inbox_id=None, updated_at=None, created_at=None, to=None, cc=None, bcc=None, has_attachments=None, unread=None, message_count=None, last_body_excerpt=None, last_text_excerpt=None, last_created_at=None, last_from=None, last_sender=None, local_vars_configuration=None):  # noqa: E501
        """EmailThreadProjection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self.__from = None
        self._subject = None
        self._sender = None
        self._recipients = None
        self._user_id = None
        self._inbox_id = None
        self._updated_at = None
        self._created_at = None
        self._to = None
        self._cc = None
        self._bcc = None
        self._has_attachments = None
        self._unread = None
        self._message_count = None
        self._last_body_excerpt = None
        self._last_text_excerpt = None
        self._last_created_at = None
        self._last_from = None
        self._last_sender = None
        self.discriminator = None

        self.id = id
        if _from is not None:
            self._from = _from
        if subject is not None:
            self.subject = subject
        if sender is not None:
            self.sender = sender
        if recipients is not None:
            self.recipients = recipients
        self.user_id = user_id
        if inbox_id is not None:
            self.inbox_id = inbox_id
        self.updated_at = updated_at
        self.created_at = created_at
        self.to = to
        if cc is not None:
            self.cc = cc
        if bcc is not None:
            self.bcc = bcc
        self.has_attachments = has_attachments
        self.unread = unread
        self.message_count = message_count
        if last_body_excerpt is not None:
            self.last_body_excerpt = last_body_excerpt
        if last_text_excerpt is not None:
            self.last_text_excerpt = last_text_excerpt
        if last_created_at is not None:
            self.last_created_at = last_created_at
        if last_from is not None:
            self.last_from = last_from
        if last_sender is not None:
            self.last_sender = last_sender

    @property
    def id(self):
        """Gets the id of this EmailThreadProjection.  # noqa: E501

        ID of email thread  # noqa: E501

        :return: The id of this EmailThreadProjection.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EmailThreadProjection.

        ID of email thread  # noqa: E501

        :param id: The id of this EmailThreadProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def _from(self):
        """Gets the _from of this EmailThreadProjection.  # noqa: E501

        From sender  # noqa: E501

        :return: The _from of this EmailThreadProjection.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this EmailThreadProjection.

        From sender  # noqa: E501

        :param _from: The _from of this EmailThreadProjection.  # noqa: E501
        :type: str
        """

        self.__from = _from

    @property
    def subject(self):
        """Gets the subject of this EmailThreadProjection.  # noqa: E501

        Thread topic subject  # noqa: E501

        :return: The subject of this EmailThreadProjection.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this EmailThreadProjection.

        Thread topic subject  # noqa: E501

        :param subject: The subject of this EmailThreadProjection.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def sender(self):
        """Gets the sender of this EmailThreadProjection.  # noqa: E501


        :return: The sender of this EmailThreadProjection.  # noqa: E501
        :rtype: SenderProjection
        """
        return self._sender

    @sender.setter
    def sender(self, sender):
        """Sets the sender of this EmailThreadProjection.


        :param sender: The sender of this EmailThreadProjection.  # noqa: E501
        :type: SenderProjection
        """

        self._sender = sender

    @property
    def recipients(self):
        """Gets the recipients of this EmailThreadProjection.  # noqa: E501


        :return: The recipients of this EmailThreadProjection.  # noqa: E501
        :rtype: EmailRecipientsProjection
        """
        return self._recipients

    @recipients.setter
    def recipients(self, recipients):
        """Sets the recipients of this EmailThreadProjection.


        :param recipients: The recipients of this EmailThreadProjection.  # noqa: E501
        :type: EmailRecipientsProjection
        """

        self._recipients = recipients

    @property
    def user_id(self):
        """Gets the user_id of this EmailThreadProjection.  # noqa: E501

        User ID  # noqa: E501

        :return: The user_id of this EmailThreadProjection.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this EmailThreadProjection.

        User ID  # noqa: E501

        :param user_id: The user_id of this EmailThreadProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def inbox_id(self):
        """Gets the inbox_id of this EmailThreadProjection.  # noqa: E501

        Inbox ID  # noqa: E501

        :return: The inbox_id of this EmailThreadProjection.  # noqa: E501
        :rtype: str
        """
        return self._inbox_id

    @inbox_id.setter
    def inbox_id(self, inbox_id):
        """Sets the inbox_id of this EmailThreadProjection.

        Inbox ID  # noqa: E501

        :param inbox_id: The inbox_id of this EmailThreadProjection.  # noqa: E501
        :type: str
        """

        self._inbox_id = inbox_id

    @property
    def updated_at(self):
        """Gets the updated_at of this EmailThreadProjection.  # noqa: E501

        Updated at DateTime  # noqa: E501

        :return: The updated_at of this EmailThreadProjection.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this EmailThreadProjection.

        Updated at DateTime  # noqa: E501

        :param updated_at: The updated_at of this EmailThreadProjection.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    @property
    def created_at(self):
        """Gets the created_at of this EmailThreadProjection.  # noqa: E501

        Created at DateTime  # noqa: E501

        :return: The created_at of this EmailThreadProjection.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this EmailThreadProjection.

        Created at DateTime  # noqa: E501

        :param created_at: The created_at of this EmailThreadProjection.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def to(self):
        """Gets the to of this EmailThreadProjection.  # noqa: E501

        To recipients  # noqa: E501

        :return: The to of this EmailThreadProjection.  # noqa: E501
        :rtype: list[str]
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this EmailThreadProjection.

        To recipients  # noqa: E501

        :param to: The to of this EmailThreadProjection.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and to is None:  # noqa: E501
            raise ValueError("Invalid value for `to`, must not be `None`")  # noqa: E501

        self._to = to

    @property
    def cc(self):
        """Gets the cc of this EmailThreadProjection.  # noqa: E501

        CC recipients  # noqa: E501

        :return: The cc of this EmailThreadProjection.  # noqa: E501
        :rtype: list[str]
        """
        return self._cc

    @cc.setter
    def cc(self, cc):
        """Sets the cc of this EmailThreadProjection.

        CC recipients  # noqa: E501

        :param cc: The cc of this EmailThreadProjection.  # noqa: E501
        :type: list[str]
        """

        self._cc = cc

    @property
    def bcc(self):
        """Gets the bcc of this EmailThreadProjection.  # noqa: E501

        BCC recipients  # noqa: E501

        :return: The bcc of this EmailThreadProjection.  # noqa: E501
        :rtype: list[str]
        """
        return self._bcc

    @bcc.setter
    def bcc(self, bcc):
        """Sets the bcc of this EmailThreadProjection.

        BCC recipients  # noqa: E501

        :param bcc: The bcc of this EmailThreadProjection.  # noqa: E501
        :type: list[str]
        """

        self._bcc = bcc

    @property
    def has_attachments(self):
        """Gets the has_attachments of this EmailThreadProjection.  # noqa: E501

        Has attachments  # noqa: E501

        :return: The has_attachments of this EmailThreadProjection.  # noqa: E501
        :rtype: bool
        """
        return self._has_attachments

    @has_attachments.setter
    def has_attachments(self, has_attachments):
        """Sets the has_attachments of this EmailThreadProjection.

        Has attachments  # noqa: E501

        :param has_attachments: The has_attachments of this EmailThreadProjection.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and has_attachments is None:  # noqa: E501
            raise ValueError("Invalid value for `has_attachments`, must not be `None`")  # noqa: E501

        self._has_attachments = has_attachments

    @property
    def unread(self):
        """Gets the unread of this EmailThreadProjection.  # noqa: E501

        Has unread  # noqa: E501

        :return: The unread of this EmailThreadProjection.  # noqa: E501
        :rtype: bool
        """
        return self._unread

    @unread.setter
    def unread(self, unread):
        """Sets the unread of this EmailThreadProjection.

        Has unread  # noqa: E501

        :param unread: The unread of this EmailThreadProjection.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and unread is None:  # noqa: E501
            raise ValueError("Invalid value for `unread`, must not be `None`")  # noqa: E501

        self._unread = unread

    @property
    def message_count(self):
        """Gets the message_count of this EmailThreadProjection.  # noqa: E501

        Number of messages in the thread  # noqa: E501

        :return: The message_count of this EmailThreadProjection.  # noqa: E501
        :rtype: int
        """
        return self._message_count

    @message_count.setter
    def message_count(self, message_count):
        """Sets the message_count of this EmailThreadProjection.

        Number of messages in the thread  # noqa: E501

        :param message_count: The message_count of this EmailThreadProjection.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and message_count is None:  # noqa: E501
            raise ValueError("Invalid value for `message_count`, must not be `None`")  # noqa: E501

        self._message_count = message_count

    @property
    def last_body_excerpt(self):
        """Gets the last_body_excerpt of this EmailThreadProjection.  # noqa: E501

        Last body excerpt  # noqa: E501

        :return: The last_body_excerpt of this EmailThreadProjection.  # noqa: E501
        :rtype: str
        """
        return self._last_body_excerpt

    @last_body_excerpt.setter
    def last_body_excerpt(self, last_body_excerpt):
        """Sets the last_body_excerpt of this EmailThreadProjection.

        Last body excerpt  # noqa: E501

        :param last_body_excerpt: The last_body_excerpt of this EmailThreadProjection.  # noqa: E501
        :type: str
        """

        self._last_body_excerpt = last_body_excerpt

    @property
    def last_text_excerpt(self):
        """Gets the last_text_excerpt of this EmailThreadProjection.  # noqa: E501

        Last text excerpt  # noqa: E501

        :return: The last_text_excerpt of this EmailThreadProjection.  # noqa: E501
        :rtype: str
        """
        return self._last_text_excerpt

    @last_text_excerpt.setter
    def last_text_excerpt(self, last_text_excerpt):
        """Sets the last_text_excerpt of this EmailThreadProjection.

        Last text excerpt  # noqa: E501

        :param last_text_excerpt: The last_text_excerpt of this EmailThreadProjection.  # noqa: E501
        :type: str
        """

        self._last_text_excerpt = last_text_excerpt

    @property
    def last_created_at(self):
        """Gets the last_created_at of this EmailThreadProjection.  # noqa: E501

        Last email created time  # noqa: E501

        :return: The last_created_at of this EmailThreadProjection.  # noqa: E501
        :rtype: datetime
        """
        return self._last_created_at

    @last_created_at.setter
    def last_created_at(self, last_created_at):
        """Sets the last_created_at of this EmailThreadProjection.

        Last email created time  # noqa: E501

        :param last_created_at: The last_created_at of this EmailThreadProjection.  # noqa: E501
        :type: datetime
        """

        self._last_created_at = last_created_at

    @property
    def last_from(self):
        """Gets the last_from of this EmailThreadProjection.  # noqa: E501

        Last sender  # noqa: E501

        :return: The last_from of this EmailThreadProjection.  # noqa: E501
        :rtype: str
        """
        return self._last_from

    @last_from.setter
    def last_from(self, last_from):
        """Sets the last_from of this EmailThreadProjection.

        Last sender  # noqa: E501

        :param last_from: The last_from of this EmailThreadProjection.  # noqa: E501
        :type: str
        """

        self._last_from = last_from

    @property
    def last_sender(self):
        """Gets the last_sender of this EmailThreadProjection.  # noqa: E501


        :return: The last_sender of this EmailThreadProjection.  # noqa: E501
        :rtype: SenderProjection
        """
        return self._last_sender

    @last_sender.setter
    def last_sender(self, last_sender):
        """Sets the last_sender of this EmailThreadProjection.


        :param last_sender: The last_sender of this EmailThreadProjection.  # noqa: E501
        :type: SenderProjection
        """

        self._last_sender = last_sender

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailThreadProjection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmailThreadProjection):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class GenerateDmarcRecordOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'domain': 'str',
        'version': 'str',
        'policy': 'str',
        'subdomain_policy': 'str',
        'report_email_address': 'list[str]',
        'forensic_email_address': 'list[str]',
        'percentage': 'int',
        'report_format': 'str',
        'seconds_between_reports': 'int',
        'adkim': 'str',
        'aspf': 'str',
        'fo': 'str'
    }

    attribute_map = {
        'domain': 'domain',
        'version': 'version',
        'policy': 'policy',
        'subdomain_policy': 'subdomainPolicy',
        'report_email_address': 'reportEmailAddress',
        'forensic_email_address': 'forensicEmailAddress',
        'percentage': 'percentage',
        'report_format': 'reportFormat',
        'seconds_between_reports': 'secondsBetweenReports',
        'adkim': 'adkim',
        'aspf': 'aspf',
        'fo': 'fo'
    }

    def __init__(self, domain=None, version=None, policy=None, subdomain_policy=None, report_email_address=None, forensic_email_address=None, percentage=None, report_format=None, seconds_between_reports=None, adkim=None, aspf=None, fo=None, local_vars_configuration=None):  # noqa: E501
        """GenerateDmarcRecordOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._domain = None
        self._version = None
        self._policy = None
        self._subdomain_policy = None
        self._report_email_address = None
        self._forensic_email_address = None
        self._percentage = None
        self._report_format = None
        self._seconds_between_reports = None
        self._adkim = None
        self._aspf = None
        self._fo = None
        self.discriminator = None

        self.domain = domain
        self.version = version
        self.policy = policy
        if subdomain_policy is not None:
            self.subdomain_policy = subdomain_policy
        if report_email_address is not None:
            self.report_email_address = report_email_address
        if forensic_email_address is not None:
            self.forensic_email_address = forensic_email_address
        if percentage is not None:
            self.percentage = percentage
        if report_format is not None:
            self.report_format = report_format
        if seconds_between_reports is not None:
            self.seconds_between_reports = seconds_between_reports
        if adkim is not None:
            self.adkim = adkim
        if aspf is not None:
            self.aspf = aspf
        if fo is not None:
            self.fo = fo

    @property
    def domain(self):
        """Gets the domain of this GenerateDmarcRecordOptions.  # noqa: E501


        :return: The domain of this GenerateDmarcRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this GenerateDmarcRecordOptions.


        :param domain: The domain of this GenerateDmarcRecordOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and domain is None:  # noqa: E501
            raise ValueError("Invalid value for `domain`, must not be `None`")  # noqa: E501

        self._domain = domain

    @property
    def version(self):
        """Gets the version of this GenerateDmarcRecordOptions.  # noqa: E501


        :return: The version of this GenerateDmarcRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this GenerateDmarcRecordOptions.


        :param version: The version of this GenerateDmarcRecordOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and version is None:  # noqa: E501
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501
        allowed_values = ["DMARC1"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and version not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `version` ({0}), must be one of {1}"  # noqa: E501
                .format(version, allowed_values)
            )

        self._version = version

    @property
    def policy(self):
        """Gets the policy of this GenerateDmarcRecordOptions.  # noqa: E501


        :return: The policy of this GenerateDmarcRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._policy

    @policy.setter
    def policy(self, policy):
        """Sets the policy of this GenerateDmarcRecordOptions.


        :param policy: The policy of this GenerateDmarcRecordOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and policy is None:  # noqa: E501
            raise ValueError("Invalid value for `policy`, must not be `None`")  # noqa: E501
        allowed_values = ["NONE", "QUARANTINE", "REJECT"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and policy not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `policy` ({0}), must be one of {1}"  # noqa: E501
                .format(policy, allowed_values)
            )

        self._policy = policy

    @property
    def subdomain_policy(self):
        """Gets the subdomain_policy of this GenerateDmarcRecordOptions.  # noqa: E501


        :return: The subdomain_policy of this GenerateDmarcRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._subdomain_policy

    @subdomain_policy.setter
    def subdomain_policy(self, subdomain_policy):
        """Sets the subdomain_policy of this GenerateDmarcRecordOptions.


        :param subdomain_policy: The subdomain_policy of this GenerateDmarcRecordOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["NONE", "QUARANTINE", "REJECT"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and subdomain_policy not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `subdomain_policy` ({0}), must be one of {1}"  # noqa: E501
                .format(subdomain_policy, allowed_values)
            )

        self._subdomain_policy = subdomain_policy

    @property
    def report_email_address(self):
        """Gets the report_email_address of this GenerateDmarcRecordOptions.  # noqa: E501


        :return: The report_email_address of this GenerateDmarcRecordOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._report_email_address

    @report_email_address.setter
    def report_email_address(self, report_email_address):
        """Sets the report_email_address of this GenerateDmarcRecordOptions.


        :param report_email_address: The report_email_address of this GenerateDmarcRecordOptions.  # noqa: E501
        :type: list[str]
        """

        self._report_email_address = report_email_address

    @property
    def forensic_email_address(self):
        """Gets the forensic_email_address of this GenerateDmarcRecordOptions.  # noqa: E501


        :return: The forensic_email_address of this GenerateDmarcRecordOptions.  # noqa: E501
        :rtype: list[str]
        """
        return self._forensic_email_address

    @forensic_email_address.setter
    def forensic_email_address(self, forensic_email_address):
        """Sets the forensic_email_address of this GenerateDmarcRecordOptions.


        :param forensic_email_address: The forensic_email_address of this GenerateDmarcRecordOptions.  # noqa: E501
        :type: list[str]
        """

        self._forensic_email_address = forensic_email_address

    @property
    def percentage(self):
        """Gets the percentage of this GenerateDmarcRecordOptions.  # noqa: E501


        :return: The percentage of this GenerateDmarcRecordOptions.  # noqa: E501
        :rtype: int
        """
        return self._percentage

    @percentage.setter
    def percentage(self, percentage):
        """Sets the percentage of this GenerateDmarcRecordOptions.


        :param percentage: The percentage of this GenerateDmarcRecordOptions.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                percentage is not None and percentage > 100):  # noqa: E501
            raise ValueError("Invalid value for `percentage`, must be a value less than or equal to `100`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                percentage is not None and percentage < 1):  # noqa: E501
            raise ValueError("Invalid value for `percentage`, must be a value greater than or equal to `1`")  # noqa: E501

        self._percentage = percentage

    @property
    def report_format(self):
        """Gets the report_format of this GenerateDmarcRecordOptions.  # noqa: E501


        :return: The report_format of this GenerateDmarcRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._report_format

    @report_format.setter
    def report_format(self, report_format):
        """Sets the report_format of this GenerateDmarcRecordOptions.


        :param report_format: The report_format of this GenerateDmarcRecordOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["AFRF"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and report_format not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `report_format` ({0}), must be one of {1}"  # noqa: E501
                .format(report_format, allowed_values)
            )

        self._report_format = report_format

    @property
    def seconds_between_reports(self):
        """Gets the seconds_between_reports of this GenerateDmarcRecordOptions.  # noqa: E501


        :return: The seconds_between_reports of this GenerateDmarcRecordOptions.  # noqa: E501
        :rtype: int
        """
        return self._seconds_between_reports

    @seconds_between_reports.setter
    def seconds_between_reports(self, seconds_between_reports):
        """Sets the seconds_between_reports of this GenerateDmarcRecordOptions.


        :param seconds_between_reports: The seconds_between_reports of this GenerateDmarcRecordOptions.  # noqa: E501
        :type: int
        """

        self._seconds_between_reports = seconds_between_reports

    @property
    def adkim(self):
        """Gets the adkim of this GenerateDmarcRecordOptions.  # noqa: E501


        :return: The adkim of this GenerateDmarcRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._adkim

    @adkim.setter
    def adkim(self, adkim):
        """Sets the adkim of this GenerateDmarcRecordOptions.


        :param adkim: The adkim of this GenerateDmarcRecordOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["STRICT", "RELAXED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and adkim not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `adkim` ({0}), must be one of {1}"  # noqa: E501
                .format(adkim, allowed_values)
            )

        self._adkim = adkim

    @property
    def aspf(self):
        """Gets the aspf of this GenerateDmarcRecordOptions.  # noqa: E501


        :return: The aspf of this GenerateDmarcRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._aspf

    @aspf.setter
    def aspf(self, aspf):
        """Sets the aspf of this GenerateDmarcRecordOptions.


        :param aspf: The aspf of this GenerateDmarcRecordOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["STRICT", "RELAXED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and aspf not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `aspf` ({0}), must be one of {1}"  # noqa: E501
                .format(aspf, allowed_values)
            )

        self._aspf = aspf

    @property
    def fo(self):
        """Gets the fo of this GenerateDmarcRecordOptions.  # noqa: E501


        :return: The fo of this GenerateDmarcRecordOptions.  # noqa: E501
        :rtype: str
        """
        return self._fo

    @fo.setter
    def fo(self, fo):
        """Sets the fo of this GenerateDmarcRecordOptions.


        :param fo: The fo of this GenerateDmarcRecordOptions.  # noqa: E501
        :type: str
        """
        allowed_values = ["FO_0", "FO_1", "FO_D", "FO_S"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and fo not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `fo` ({0}), must be one of {1}"  # noqa: E501
                .format(fo, allowed_values)
            )

        self._fo = fo

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GenerateDmarcRecordOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GenerateDmarcRecordOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class SendOptInConsentEmailOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'template_html': 'str',
        'subject': 'str',
        'sender_inbox': 'str'
    }

    attribute_map = {
        'template_html': 'templateHtml',
        'subject': 'subject',
        'sender_inbox': 'senderInbox'
    }

    def __init__(self, template_html=None, subject=None, sender_inbox=None, local_vars_configuration=None):  # noqa: E501
        """SendOptInConsentEmailOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._template_html = None
        self._subject = None
        self._sender_inbox = None
        self.discriminator = None

        self.template_html = template_html
        self.subject = subject
        if sender_inbox is not None:
            self.sender_inbox = sender_inbox

    @property
    def template_html(self):
        """Gets the template_html of this SendOptInConsentEmailOptions.  # noqa: E501


        :return: The template_html of this SendOptInConsentEmailOptions.  # noqa: E501
        :rtype: str
        """
        return self._template_html

    @template_html.setter
    def template_html(self, template_html):
        """Sets the template_html of this SendOptInConsentEmailOptions.


        :param template_html: The template_html of this SendOptInConsentEmailOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and template_html is None:  # noqa: E501
            raise ValueError("Invalid value for `template_html`, must not be `None`")  # noqa: E501

        self._template_html = template_html

    @property
    def subject(self):
        """Gets the subject of this SendOptInConsentEmailOptions.  # noqa: E501


        :return: The subject of this SendOptInConsentEmailOptions.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this SendOptInConsentEmailOptions.


        :param subject: The subject of this SendOptInConsentEmailOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and subject is None:  # noqa: E501
            raise ValueError("Invalid value for `subject`, must not be `None`")  # noqa: E501

        self._subject = subject

    @property
    def sender_inbox(self):
        """Gets the sender_inbox of this SendOptInConsentEmailOptions.  # noqa: E501


        :return: The sender_inbox of this SendOptInConsentEmailOptions.  # noqa: E501
        :rtype: str
        """
        return self._sender_inbox

    @sender_inbox.setter
    def sender_inbox(self, sender_inbox):
        """Sets the sender_inbox of this SendOptInConsentEmailOptions.


        :param sender_inbox: The sender_inbox of this SendOptInConsentEmailOptions.  # noqa: E501
        :type: str
        """

        self._sender_inbox = sender_inbox

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SendOptInConsentEmailOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SendOptInConsentEmailOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DeliverabilitySimulationEmailOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'from_override': 'str',
        'subject': 'str',
        'body_template': 'str'
    }

    attribute_map = {
        'from_override': 'fromOverride',
        'subject': 'subject',
        'body_template': 'bodyTemplate'
    }

    def __init__(self, from_override=None, subject=None, body_template=None, local_vars_configuration=None):  # noqa: E501
        """DeliverabilitySimulationEmailOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._from_override = None
        self._subject = None
        self._body_template = None
        self.discriminator = None

        self.from_override = from_override
        self.subject = subject
        self.body_template = body_template

    @property
    def from_override(self):
        """Gets the from_override of this DeliverabilitySimulationEmailOptions.  # noqa: E501

        Optional from override for each sent email  # noqa: E501

        :return: The from_override of this DeliverabilitySimulationEmailOptions.  # noqa: E501
        :rtype: str
        """
        return self._from_override

    @from_override.setter
    def from_override(self, from_override):
        """Sets the from_override of this DeliverabilitySimulationEmailOptions.

        Optional from override for each sent email  # noqa: E501

        :param from_override: The from_override of this DeliverabilitySimulationEmailOptions.  # noqa: E501
        :type: str
        """

        self._from_override = from_override

    @property
    def subject(self):
        """Gets the subject of this DeliverabilitySimulationEmailOptions.  # noqa: E501

        Optional email subject fallback used when template subject is omitted  # noqa: E501

        :return: The subject of this DeliverabilitySimulationEmailOptions.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this DeliverabilitySimulationEmailOptions.

        Optional email subject fallback used when template subject is omitted  # noqa: E501

        :param subject: The subject of this DeliverabilitySimulationEmailOptions.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def body_template(self):
        """Gets the body_template of this DeliverabilitySimulationEmailOptions.  # noqa: E501

        Optional email body template. Supports {{targetLabel}}, {{sendIndex}}, {{attempt}}.  # noqa: E501

        :return: The body_template of this DeliverabilitySimulationEmailOptions.  # noqa: E501
        :rtype: str
        """
        return self._body_template

    @body_template.setter
    def body_template(self, body_template):
        """Sets the body_template of this DeliverabilitySimulationEmailOptions.

        Optional email body template. Supports {{targetLabel}}, {{sendIndex}}, {{attempt}}.  # noqa: E501

        :param body_template: The body_template of this DeliverabilitySimulationEmailOptions.  # noqa: E501
        :type: str
        """

        self._body_template = body_template

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeliverabilitySimulationEmailOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeliverabilitySimulationEmailOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PhonePoolMemberDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'pool_id': 'str',
        'phone_number_id': 'str',
        'phone_number': 'str',
        'phone_country': 'str',
        'phone_name': 'str',
        'created_at': 'datetime',
        'active_lease': 'PhonePoolLeaseDto'
    }

    attribute_map = {
        'id': 'id',
        'pool_id': 'poolId',
        'phone_number_id': 'phoneNumberId',
        'phone_number': 'phoneNumber',
        'phone_country': 'phoneCountry',
        'phone_name': 'phoneName',
        'created_at': 'createdAt',
        'active_lease': 'activeLease'
    }

    def __init__(self, id=None, pool_id=None, phone_number_id=None, phone_number=None, phone_country=None, phone_name=None, created_at=None, active_lease=None, local_vars_configuration=None):  # noqa: E501
        """PhonePoolMemberDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._pool_id = None
        self._phone_number_id = None
        self._phone_number = None
        self._phone_country = None
        self._phone_name = None
        self._created_at = None
        self._active_lease = None
        self.discriminator = None

        self.id = id
        self.pool_id = pool_id
        self.phone_number_id = phone_number_id
        self.phone_number = phone_number
        self.phone_country = phone_country
        if phone_name is not None:
            self.phone_name = phone_name
        self.created_at = created_at
        if active_lease is not None:
            self.active_lease = active_lease

    @property
    def id(self):
        """Gets the id of this PhonePoolMemberDto.  # noqa: E501


        :return: The id of this PhonePoolMemberDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PhonePoolMemberDto.


        :param id: The id of this PhonePoolMemberDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def pool_id(self):
        """Gets the pool_id of this PhonePoolMemberDto.  # noqa: E501


        :return: The pool_id of this PhonePoolMemberDto.  # noqa: E501
        :rtype: str
        """
        return self._pool_id

    @pool_id.setter
    def pool_id(self, pool_id):
        """Sets the pool_id of this PhonePoolMemberDto.


        :param pool_id: The pool_id of this PhonePoolMemberDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and pool_id is None:  # noqa: E501
            raise ValueError("Invalid value for `pool_id`, must not be `None`")  # noqa: E501

        self._pool_id = pool_id

    @property
    def phone_number_id(self):
        """Gets the phone_number_id of this PhonePoolMemberDto.  # noqa: E501


        :return: The phone_number_id of this PhonePoolMemberDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_number_id

    @phone_number_id.setter
    def phone_number_id(self, phone_number_id):
        """Sets the phone_number_id of this PhonePoolMemberDto.


        :param phone_number_id: The phone_number_id of this PhonePoolMemberDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_number_id is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_number_id`, must not be `None`")  # noqa: E501

        self._phone_number_id = phone_number_id

    @property
    def phone_number(self):
        """Gets the phone_number of this PhonePoolMemberDto.  # noqa: E501


        :return: The phone_number of this PhonePoolMemberDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this PhonePoolMemberDto.


        :param phone_number: The phone_number of this PhonePoolMemberDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_number is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_number`, must not be `None`")  # noqa: E501

        self._phone_number = phone_number

    @property
    def phone_country(self):
        """Gets the phone_country of this PhonePoolMemberDto.  # noqa: E501


        :return: The phone_country of this PhonePoolMemberDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_country

    @phone_country.setter
    def phone_country(self, phone_country):
        """Sets the phone_country of this PhonePoolMemberDto.


        :param phone_country: The phone_country of this PhonePoolMemberDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and phone_country is None:  # noqa: E501
            raise ValueError("Invalid value for `phone_country`, must not be `None`")  # noqa: E501
        allowed_values = ["US", "GB", "AU", "CA", "EE", "HK", "PL", "PT", "NL", "IL", "FI", "SE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_country not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_country` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_country, allowed_values)
            )

        self._phone_country = phone_country

    @property
    def phone_name(self):
        """Gets the phone_name of this PhonePoolMemberDto.  # noqa: E501


        :return: The phone_name of this PhonePoolMemberDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_name

    @phone_name.setter
    def phone_name(self, phone_name):
        """Sets the phone_name of this PhonePoolMemberDto.


        :param phone_name: The phone_name of this PhonePoolMemberDto.  # noqa: E501
        :type: str
        """

        self._phone_name = phone_name

    @property
    def created_at(self):
        """Gets the created_at of this PhonePoolMemberDto.  # noqa: E501


        :return: The created_at of this PhonePoolMemberDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PhonePoolMemberDto.


        :param created_at: The created_at of this PhonePoolMemberDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def active_lease(self):
        """Gets the active_lease of this PhonePoolMemberDto.  # noqa: E501


        :return: The active_lease of this PhonePoolMemberDto.  # noqa: E501
        :rtype: PhonePoolLeaseDto
        """
        return self._active_lease

    @active_lease.setter
    def active_lease(self, active_lease):
        """Sets the active_lease of this PhonePoolMemberDto.


        :param active_lease: The active_lease of this PhonePoolMemberDto.  # noqa: E501
        :type: PhonePoolLeaseDto
        """

        self._active_lease = active_lease

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PhonePoolMemberDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PhonePoolMemberDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class InboxRulesetTestResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ruleset_matches': 'dict(str, bool)',
        'matches': 'bool'
    }

    attribute_map = {
        'ruleset_matches': 'rulesetMatches',
        'matches': 'matches'
    }

    def __init__(self, ruleset_matches=None, matches=None, local_vars_configuration=None):  # noqa: E501
        """InboxRulesetTestResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._ruleset_matches = None
        self._matches = None
        self.discriminator = None

        self.ruleset_matches = ruleset_matches
        self.matches = matches

    @property
    def ruleset_matches(self):
        """Gets the ruleset_matches of this InboxRulesetTestResult.  # noqa: E501

        Map of inbox ruleset ID to boolean of if target matches  # noqa: E501

        :return: The ruleset_matches of this InboxRulesetTestResult.  # noqa: E501
        :rtype: dict(str, bool)
        """
        return self._ruleset_matches

    @ruleset_matches.setter
    def ruleset_matches(self, ruleset_matches):
        """Sets the ruleset_matches of this InboxRulesetTestResult.

        Map of inbox ruleset ID to boolean of if target matches  # noqa: E501

        :param ruleset_matches: The ruleset_matches of this InboxRulesetTestResult.  # noqa: E501
        :type: dict(str, bool)
        """
        if self.local_vars_configuration.client_side_validation and ruleset_matches is None:  # noqa: E501
            raise ValueError("Invalid value for `ruleset_matches`, must not be `None`")  # noqa: E501

        self._ruleset_matches = ruleset_matches

    @property
    def matches(self):
        """Gets the matches of this InboxRulesetTestResult.  # noqa: E501


        :return: The matches of this InboxRulesetTestResult.  # noqa: E501
        :rtype: bool
        """
        return self._matches

    @matches.setter
    def matches(self, matches):
        """Sets the matches of this InboxRulesetTestResult.


        :param matches: The matches of this InboxRulesetTestResult.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and matches is None:  # noqa: E501
            raise ValueError("Invalid value for `matches`, must not be `None`")  # noqa: E501

        self._matches = matches

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InboxRulesetTestResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InboxRulesetTestResult):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class ExtractAttachmentTextOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'method': 'str',
        'allow_fallback': 'bool',
        'max_bytes': 'int'
    }

    attribute_map = {
        'method': 'method',
        'allow_fallback': 'allowFallback',
        'max_bytes': 'maxBytes'
    }

    def __init__(self, method=None, allow_fallback=True, max_bytes=1048576, local_vars_configuration=None):  # noqa: E501
        """ExtractAttachmentTextOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._method = None
        self._allow_fallback = None
        self._max_bytes = None
        self.discriminator = None

        self.method = method
        if allow_fallback is not None:
            self.allow_fallback = allow_fallback
        self.max_bytes = max_bytes

    @property
    def method(self):
        """Gets the method of this ExtractAttachmentTextOptions.  # noqa: E501

        Method for extracting text from attachments.  # noqa: E501

        :return: The method of this ExtractAttachmentTextOptions.  # noqa: E501
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this ExtractAttachmentTextOptions.

        Method for extracting text from attachments.  # noqa: E501

        :param method: The method of this ExtractAttachmentTextOptions.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"AUTO", "NATIVE", "OCR", "LLM", "OCR_THEN_LLM"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and method not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `method` ({0}), must be one of {1}"  # noqa: E501
                .format(method, allowed_values)
            )

        self._method = method

    @property
    def allow_fallback(self):
        """Gets the allow_fallback of this ExtractAttachmentTextOptions.  # noqa: E501

        Allow fallback to native extraction when the selected method is unavailable.  # noqa: E501

        :return: The allow_fallback of this ExtractAttachmentTextOptions.  # noqa: E501
        :rtype: bool
        """
        return self._allow_fallback

    @allow_fallback.setter
    def allow_fallback(self, allow_fallback):
        """Sets the allow_fallback of this ExtractAttachmentTextOptions.

        Allow fallback to native extraction when the selected method is unavailable.  # noqa: E501

        :param allow_fallback: The allow_fallback of this ExtractAttachmentTextOptions.  # noqa: E501
        :type: bool
        """

        self._allow_fallback = allow_fallback

    @property
    def max_bytes(self):
        """Gets the max_bytes of this ExtractAttachmentTextOptions.  # noqa: E501

        Maximum bytes to read from attachment for native text extraction.  # noqa: E501

        :return: The max_bytes of this ExtractAttachmentTextOptions.  # noqa: E501
        :rtype: int
        """
        return self._max_bytes

    @max_bytes.setter
    def max_bytes(self, max_bytes):
        """Sets the max_bytes of this ExtractAttachmentTextOptions.

        Maximum bytes to read from attachment for native text extraction.  # noqa: E501

        :param max_bytes: The max_bytes of this ExtractAttachmentTextOptions.  # noqa: E501
        :type: int
        """

        self._max_bytes = max_bytes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExtractAttachmentTextOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ExtractAttachmentTextOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class TestSmtpServerOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'host': 'str',
        'port': 'int',
        'use_start_tls': 'bool',
        'username': 'str',
        'password': 'str',
        '_from': 'str',
        'to': 'str',
        'captcha_token': 'str'
    }

    attribute_map = {
        'host': 'host',
        'port': 'port',
        'use_start_tls': 'useStartTls',
        'username': 'username',
        'password': 'password',
        '_from': 'from',
        'to': 'to',
        'captcha_token': 'captchaToken'
    }

    def __init__(self, host=None, port=None, use_start_tls=None, username=None, password=None, _from=None, to=None, captcha_token=None, local_vars_configuration=None):  # noqa: E501
        """TestSmtpServerOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._host = None
        self._port = None
        self._use_start_tls = None
        self._username = None
        self._password = None
        self.__from = None
        self._to = None
        self._captcha_token = None
        self.discriminator = None

        self.host = host
        self.port = port
        self.use_start_tls = use_start_tls
        self.username = username
        self.password = password
        self._from = _from
        self.to = to
        self.captcha_token = captcha_token

    @property
    def host(self):
        """Gets the host of this TestSmtpServerOptions.  # noqa: E501

        SMTP host name or IP address  # noqa: E501

        :return: The host of this TestSmtpServerOptions.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this TestSmtpServerOptions.

        SMTP host name or IP address  # noqa: E501

        :param host: The host of this TestSmtpServerOptions.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and host is None:  # noqa: E501
            raise ValueError("Invalid value for `host`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                host is not None and len(host) < 1):
            raise ValueError("Invalid value for `host`, length must be greater than or equal to `1`")  # noqa: E501

        self._host = host

    @property
    def port(self):
        """Gets the port of this TestSmtpServerOptions.  # noqa: E501


        :return: The port of this TestSmtpServerOptions.  # noqa: E501
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this TestSmtpServerOptions.


        :param port: The port of this TestSmtpServerOptions.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and port is None:  # noqa: E501
            raise ValueError("Invalid value for `port`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                port is not None and port > 65535):  # noqa: E501
            raise ValueError("Invalid value for `port`, must be a value less than or equal to `65535`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                port is not None and port < 1):  # noqa: E501
            raise ValueError("Invalid value for `port`, must be a value greater than or equal to `1`")  # noqa: E501

        self._port = port

    @property
    def use_start_tls(self):
        """Gets the use_start_tls of this TestSmtpServerOptions.  # noqa: E501


        :return: The use_start_tls of this TestSmtpServerOptions.  # noqa: E501
        :rtype: bool
        """
        return self._use_start_tls

    @use_start_tls.setter
    def use_start_tls(self, use_start_tls):
        """Sets the use_start_tls of this TestSmtpServerOptions.


        :param use_start_tls: The use_start_tls of this TestSmtpServerOptions.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and use_start_tls is None:  # noqa: E501
            raise ValueError("Invalid value for `use_start_tls`, must not be `None`")  # noqa: E501

        self._use_start_tls = use_start_tls

    @property
    def username(self):
        """Gets the username of this TestSmtpServerOptions.  # noqa: E501


        :return: The username of this TestSmtpServerOptions.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this TestSmtpServerOptions.


        :param username: The username of this TestSmtpServerOptions.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def password(self):
        """Gets the password of this TestSmtpServerOptions.  # noqa: E501


        :return: The password of this TestSmtpServerOptions.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this TestSmtpServerOptions.


        :param password: The password of this TestSmtpServerOptions.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def _from(self):
        """Gets the _from of this TestSmtpServerOptions.  # noqa: E501


        :return: The _from of this TestSmtpServerOptions.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this TestSmtpServerOptions.


        :param _from: The _from of this TestSmtpServerOptions.  # noqa: E501
        :type: str
        """

        self.__from = _from

    @property
    def to(self):
        """Gets the to of this TestSmtpServerOptions.  # noqa: E501


        :return: The to of this TestSmtpServerOptions.  # noqa: E501
        :rtype: str
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this TestSmtpServerOptions.


        :param to: The to of this TestSmtpServerOptions.  # noqa: E501
        :type: str
        """

        self._to = to

    @property
    def captcha_token(self):
        """Gets the captcha_token of this TestSmtpServerOptions.  # noqa: E501


        :return: The captcha_token of this TestSmtpServerOptions.  # noqa: E501
        :rtype: str
        """
        return self._captcha_token

    @captcha_token.setter
    def captcha_token(self, captcha_token):
        """Sets the captcha_token of this TestSmtpServerOptions.


        :param captcha_token: The captcha_token of this TestSmtpServerOptions.  # noqa: E501
        :type: str
        """

        self._captcha_token = captcha_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TestSmtpServerOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TestSmtpServerOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class MissedEmailDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'str',
        'subject': 'str',
        'body_excerpt': 'str',
        'attachment_count': 'int',
        '_from': 'str',
        'raw_url': 'str',
        'raw_key': 'str',
        'raw_bucket': 'str',
        'can_restore': 'bool',
        'to': 'list[str]',
        'cc': 'list[str]',
        'bcc': 'list[str]',
        'inbox_ids': 'list[str]',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'subject': 'subject',
        'body_excerpt': 'bodyExcerpt',
        'attachment_count': 'attachmentCount',
        '_from': 'from',
        'raw_url': 'rawUrl',
        'raw_key': 'rawKey',
        'raw_bucket': 'rawBucket',
        'can_restore': 'canRestore',
        'to': 'to',
        'cc': 'cc',
        'bcc': 'bcc',
        'inbox_ids': 'inboxIds',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, user_id=None, subject=None, body_excerpt=None, attachment_count=None, _from=None, raw_url=None, raw_key=None, raw_bucket=None, can_restore=None, to=None, cc=None, bcc=None, inbox_ids=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """MissedEmailDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_id = None
        self._subject = None
        self._body_excerpt = None
        self._attachment_count = None
        self.__from = None
        self._raw_url = None
        self._raw_key = None
        self._raw_bucket = None
        self._can_restore = None
        self._to = None
        self._cc = None
        self._bcc = None
        self._inbox_ids = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        self.id = id
        self.user_id = user_id
        self.subject = subject
        self.body_excerpt = body_excerpt
        self.attachment_count = attachment_count
        self._from = _from
        self.raw_url = raw_url
        self.raw_key = raw_key
        self.raw_bucket = raw_bucket
        self.can_restore = can_restore
        self.to = to
        self.cc = cc
        self.bcc = bcc
        self.inbox_ids = inbox_ids
        self.created_at = created_at
        self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this MissedEmailDto.  # noqa: E501


        :return: The id of this MissedEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MissedEmailDto.


        :param id: The id of this MissedEmailDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this MissedEmailDto.  # noqa: E501


        :return: The user_id of this MissedEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this MissedEmailDto.


        :param user_id: The user_id of this MissedEmailDto.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def subject(self):
        """Gets the subject of this MissedEmailDto.  # noqa: E501


        :return: The subject of this MissedEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this MissedEmailDto.


        :param subject: The subject of this MissedEmailDto.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def body_excerpt(self):
        """Gets the body_excerpt of this MissedEmailDto.  # noqa: E501


        :return: The body_excerpt of this MissedEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._body_excerpt

    @body_excerpt.setter
    def body_excerpt(self, body_excerpt):
        """Sets the body_excerpt of this MissedEmailDto.


        :param body_excerpt: The body_excerpt of this MissedEmailDto.  # noqa: E501
        :type: str
        """

        self._body_excerpt = body_excerpt

    @property
    def attachment_count(self):
        """Gets the attachment_count of this MissedEmailDto.  # noqa: E501


        :return: The attachment_count of this MissedEmailDto.  # noqa: E501
        :rtype: int
        """
        return self._attachment_count

    @attachment_count.setter
    def attachment_count(self, attachment_count):
        """Sets the attachment_count of this MissedEmailDto.


        :param attachment_count: The attachment_count of this MissedEmailDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and attachment_count is None:  # noqa: E501
            raise ValueError("Invalid value for `attachment_count`, must not be `None`")  # noqa: E501

        self._attachment_count = attachment_count

    @property
    def _from(self):
        """Gets the _from of this MissedEmailDto.  # noqa: E501


        :return: The _from of this MissedEmailDto.  # noqa: E501
        :rtype: str
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this MissedEmailDto.


        :param _from: The _from of this MissedEmailDto.  # noqa: E501
        :type: str
        """

        self.__from = _from

    @property
    def raw_url(self):
        """Gets the raw_url of this MissedEmailDto.  # noqa: E501

        use raw key and raw bucket  # noqa: E501

        :return: The raw_url of this MissedEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._raw_url

    @raw_url.setter
    def raw_url(self, raw_url):
        """Sets the raw_url of this MissedEmailDto.

        use raw key and raw bucket  # noqa: E501

        :param raw_url: The raw_url of this MissedEmailDto.  # noqa: E501
        :type: str
        """

        self._raw_url = raw_url

    @property
    def raw_key(self):
        """Gets the raw_key of this MissedEmailDto.  # noqa: E501


        :return: The raw_key of this MissedEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._raw_key

    @raw_key.setter
    def raw_key(self, raw_key):
        """Sets the raw_key of this MissedEmailDto.


        :param raw_key: The raw_key of this MissedEmailDto.  # noqa: E501
        :type: str
        """

        self._raw_key = raw_key

    @property
    def raw_bucket(self):
        """Gets the raw_bucket of this MissedEmailDto.  # noqa: E501


        :return: The raw_bucket of this MissedEmailDto.  # noqa: E501
        :rtype: str
        """
        return self._raw_bucket

    @raw_bucket.setter
    def raw_bucket(self, raw_bucket):
        """Sets the raw_bucket of this MissedEmailDto.


        :param raw_bucket: The raw_bucket of this MissedEmailDto.  # noqa: E501
        :type: str
        """

        self._raw_bucket = raw_bucket

    @property
    def can_restore(self):
        """Gets the can_restore of this MissedEmailDto.  # noqa: E501


        :return: The can_restore of this MissedEmailDto.  # noqa: E501
        :rtype: bool
        """
        return self._can_restore

    @can_restore.setter
    def can_restore(self, can_restore):
        """Sets the can_restore of this MissedEmailDto.


        :param can_restore: The can_restore of this MissedEmailDto.  # noqa: E501
        :type: bool
        """

        self._can_restore = can_restore

    @property
    def to(self):
        """Gets the to of this MissedEmailDto.  # noqa: E501


        :return: The to of this MissedEmailDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this MissedEmailDto.


        :param to: The to of this MissedEmailDto.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and to is None:  # noqa: E501
            raise ValueError("Invalid value for `to`, must not be `None`")  # noqa: E501

        self._to = to

    @property
    def cc(self):
        """Gets the cc of this MissedEmailDto.  # noqa: E501


        :return: The cc of this MissedEmailDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._cc

    @cc.setter
    def cc(self, cc):
        """Sets the cc of this MissedEmailDto.


        :param cc: The cc of this MissedEmailDto.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and cc is None:  # noqa: E501
            raise ValueError("Invalid value for `cc`, must not be `None`")  # noqa: E501

        self._cc = cc

    @property
    def bcc(self):
        """Gets the bcc of this MissedEmailDto.  # noqa: E501


        :return: The bcc of this MissedEmailDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._bcc

    @bcc.setter
    def bcc(self, bcc):
        """Sets the bcc of this MissedEmailDto.


        :param bcc: The bcc of this MissedEmailDto.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and bcc is None:  # noqa: E501
            raise ValueError("Invalid value for `bcc`, must not be `None`")  # noqa: E501

        self._bcc = bcc

    @property
    def inbox_ids(self):
        """Gets the inbox_ids of this MissedEmailDto.  # noqa: E501


        :return: The inbox_ids of this MissedEmailDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._inbox_ids

    @inbox_ids.setter
    def inbox_ids(self, inbox_ids):
        """Sets the inbox_ids of this MissedEmailDto.


        :param inbox_ids: The inbox_ids of this MissedEmailDto.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and inbox_ids is None:  # noqa: E501
            raise ValueError("Invalid value for `inbox_ids`, must not be `None`")  # noqa: E501

        self._inbox_ids = inbox_ids

    @property
    def created_at(self):
        """Gets the created_at of this MissedEmailDto.  # noqa: E501


        :return: The created_at of this MissedEmailDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this MissedEmailDto.


        :param created_at: The created_at of this MissedEmailDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this MissedEmailDto.  # noqa: E501


        :return: The updated_at of this MissedEmailDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this MissedEmailDto.


        :param updated_at: The updated_at of this MissedEmailDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MissedEmailDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MissedEmailDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DeliverabilityEntityResultDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'entity_id': 'str',
        'entity_label': 'str',
        'matched': 'bool',
        'matched_expectation_count': 'int',
        'total_expectation_count': 'int',
        'phone_country': 'str',
        'phone_variant': 'str',
        'evaluated_at': 'datetime',
        'expectation_results': 'list[DeliverabilityExpectationResultDto]'
    }

    attribute_map = {
        'entity_id': 'entityId',
        'entity_label': 'entityLabel',
        'matched': 'matched',
        'matched_expectation_count': 'matchedExpectationCount',
        'total_expectation_count': 'totalExpectationCount',
        'phone_country': 'phoneCountry',
        'phone_variant': 'phoneVariant',
        'evaluated_at': 'evaluatedAt',
        'expectation_results': 'expectationResults'
    }

    def __init__(self, entity_id=None, entity_label=None, matched=None, matched_expectation_count=None, total_expectation_count=None, phone_country=None, phone_variant=None, evaluated_at=None, expectation_results=None, local_vars_configuration=None):  # noqa: E501
        """DeliverabilityEntityResultDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._entity_id = None
        self._entity_label = None
        self._matched = None
        self._matched_expectation_count = None
        self._total_expectation_count = None
        self._phone_country = None
        self._phone_variant = None
        self._evaluated_at = None
        self._expectation_results = None
        self.discriminator = None

        self.entity_id = entity_id
        self.entity_label = entity_label
        self.matched = matched
        self.matched_expectation_count = matched_expectation_count
        self.total_expectation_count = total_expectation_count
        self.phone_country = phone_country
        self.phone_variant = phone_variant
        self.evaluated_at = evaluated_at
        self.expectation_results = expectation_results

    @property
    def entity_id(self):
        """Gets the entity_id of this DeliverabilityEntityResultDto.  # noqa: E501


        :return: The entity_id of this DeliverabilityEntityResultDto.  # noqa: E501
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """Sets the entity_id of this DeliverabilityEntityResultDto.


        :param entity_id: The entity_id of this DeliverabilityEntityResultDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and entity_id is None:  # noqa: E501
            raise ValueError("Invalid value for `entity_id`, must not be `None`")  # noqa: E501

        self._entity_id = entity_id

    @property
    def entity_label(self):
        """Gets the entity_label of this DeliverabilityEntityResultDto.  # noqa: E501


        :return: The entity_label of this DeliverabilityEntityResultDto.  # noqa: E501
        :rtype: str
        """
        return self._entity_label

    @entity_label.setter
    def entity_label(self, entity_label):
        """Sets the entity_label of this DeliverabilityEntityResultDto.


        :param entity_label: The entity_label of this DeliverabilityEntityResultDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and entity_label is None:  # noqa: E501
            raise ValueError("Invalid value for `entity_label`, must not be `None`")  # noqa: E501

        self._entity_label = entity_label

    @property
    def matched(self):
        """Gets the matched of this DeliverabilityEntityResultDto.  # noqa: E501


        :return: The matched of this DeliverabilityEntityResultDto.  # noqa: E501
        :rtype: bool
        """
        return self._matched

    @matched.setter
    def matched(self, matched):
        """Sets the matched of this DeliverabilityEntityResultDto.


        :param matched: The matched of this DeliverabilityEntityResultDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and matched is None:  # noqa: E501
            raise ValueError("Invalid value for `matched`, must not be `None`")  # noqa: E501

        self._matched = matched

    @property
    def matched_expectation_count(self):
        """Gets the matched_expectation_count of this DeliverabilityEntityResultDto.  # noqa: E501


        :return: The matched_expectation_count of this DeliverabilityEntityResultDto.  # noqa: E501
        :rtype: int
        """
        return self._matched_expectation_count

    @matched_expectation_count.setter
    def matched_expectation_count(self, matched_expectation_count):
        """Sets the matched_expectation_count of this DeliverabilityEntityResultDto.


        :param matched_expectation_count: The matched_expectation_count of this DeliverabilityEntityResultDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and matched_expectation_count is None:  # noqa: E501
            raise ValueError("Invalid value for `matched_expectation_count`, must not be `None`")  # noqa: E501

        self._matched_expectation_count = matched_expectation_count

    @property
    def total_expectation_count(self):
        """Gets the total_expectation_count of this DeliverabilityEntityResultDto.  # noqa: E501


        :return: The total_expectation_count of this DeliverabilityEntityResultDto.  # noqa: E501
        :rtype: int
        """
        return self._total_expectation_count

    @total_expectation_count.setter
    def total_expectation_count(self, total_expectation_count):
        """Sets the total_expectation_count of this DeliverabilityEntityResultDto.


        :param total_expectation_count: The total_expectation_count of this DeliverabilityEntityResultDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_expectation_count is None:  # noqa: E501
            raise ValueError("Invalid value for `total_expectation_count`, must not be `None`")  # noqa: E501

        self._total_expectation_count = total_expectation_count

    @property
    def phone_country(self):
        """Gets the phone_country of this DeliverabilityEntityResultDto.  # noqa: E501


        :return: The phone_country of this DeliverabilityEntityResultDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_country

    @phone_country.setter
    def phone_country(self, phone_country):
        """Sets the phone_country of this DeliverabilityEntityResultDto.


        :param phone_country: The phone_country of this DeliverabilityEntityResultDto.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"US", "GB", "AU", "CA", "EE", "HK", "PL", "PT", "NL", "IL", "FI", "SE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_country not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_country` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_country, allowed_values)
            )

        self._phone_country = phone_country

    @property
    def phone_variant(self):
        """Gets the phone_variant of this DeliverabilityEntityResultDto.  # noqa: E501


        :return: The phone_variant of this DeliverabilityEntityResultDto.  # noqa: E501
        :rtype: str
        """
        return self._phone_variant

    @phone_variant.setter
    def phone_variant(self, phone_variant):
        """Sets the phone_variant of this DeliverabilityEntityResultDto.


        :param phone_variant: The phone_variant of this DeliverabilityEntityResultDto.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"LOCAL", "MOBILE", "TOLL_FREE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and phone_variant not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `phone_variant` ({0}), must be one of {1}"  # noqa: E501
                .format(phone_variant, allowed_values)
            )

        self._phone_variant = phone_variant

    @property
    def evaluated_at(self):
        """Gets the evaluated_at of this DeliverabilityEntityResultDto.  # noqa: E501


        :return: The evaluated_at of this DeliverabilityEntityResultDto.  # noqa: E501
        :rtype: datetime
        """
        return self._evaluated_at

    @evaluated_at.setter
    def evaluated_at(self, evaluated_at):
        """Sets the evaluated_at of this DeliverabilityEntityResultDto.


        :param evaluated_at: The evaluated_at of this DeliverabilityEntityResultDto.  # noqa: E501
        :type: datetime
        """

        self._evaluated_at = evaluated_at

    @property
    def expectation_results(self):
        """Gets the expectation_results of this DeliverabilityEntityResultDto.  # noqa: E501


        :return: The expectation_results of this DeliverabilityEntityResultDto.  # noqa: E501
        :rtype: list[DeliverabilityExpectationResultDto]
        """
        return self._expectation_results

    @expectation_results.setter
    def expectation_results(self, expectation_results):
        """Sets the expectation_results of this DeliverabilityEntityResultDto.


        :param expectation_results: The expectation_results of this DeliverabilityEntityResultDto.  # noqa: E501
        :type: list[DeliverabilityExpectationResultDto]
        """
        if self.local_vars_configuration.client_side_validation and expectation_results is None:  # noqa: E501
            raise ValueError("Invalid value for `expectation_results`, must not be `None`")  # noqa: E501

        self._expectation_results = expectation_results

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeliverabilityEntityResultDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeliverabilityEntityResultDto):
            return True

        return self.to_dict() != other.to_dict()
